aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/nvim/auevents.lua8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/nvim/auevents.lua b/src/nvim/auevents.lua
index e6285c5c76..a6290aaac1 100644
--- a/src/nvim/auevents.lua
+++ b/src/nvim/auevents.lua
@@ -19,8 +19,8 @@ return {
'BufWriteCmd', -- write buffer using command
'BufWritePost', -- after writing a buffer
'BufWritePre', -- before writing a buffer
- 'ChanOpen', -- channel was opened
'ChanInfo', -- info was received about channel
+ 'ChanOpen', -- channel was opened
'CmdLineEnter', -- after entering cmdline mode
'CmdLineLeave', -- before leaving cmdline mode
'CmdUndefined', -- command undefined
@@ -99,9 +99,9 @@ return {
'VimResized', -- after Vim window was resized
'VimResume', -- after Nvim is resumed
'VimSuspend', -- before Nvim is suspended
- 'WinNew', -- when entering a new window
'WinEnter', -- after entering a window
'WinLeave', -- before leaving a window
+ 'WinNew', -- when entering a new window
},
aliases = {
BufCreate = 'BufAdd',
@@ -109,9 +109,9 @@ return {
BufWrite = 'BufWritePre',
FileEncoding = 'EncodingChanged',
},
- -- List of neovim-specific events or aliases for the purpose of generating
+ -- List of nvim-specific events or aliases for the purpose of generating
-- syntax file
- neovim_specific = {
+ nvim_specific = {
DirChanged=true,
TabClosed=true,
TabNew=true,